==> ejc-riskmortgage-impl-3.0.0-20231122.083741-80-sources.jar: com/ejianc/business/collect/bean/CollectEntity.java <==
package com.ejianc.business.collect.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 兑现计算汇总表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_cash_collect")
public class CollectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_org_id")
    private Long projectOrgId; // 项目所属组织id
    @TableField(value="project_org_code")
    private String projectOrgCode; // 项目所属组织编码
    @TableField(value="project_org_name")
    private String projectOrgName; // 项目所属组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_code")
    private String departmentCode; // 经办人部门编码
    @TableField(value="department_name")
    private String departmentName; // 经办人部门名称
    @TableField(value="node_stage")
    private String nodeStage; // 节点阶段
    @TableField(value="engineering_mny")
    private BigDecimal engineeringMny; // 工程造价
    @TableField(value="engineering_tax")
    private BigDecimal engineeringTax; // 工程税金
    @TableField(value="rg_mny")
    private BigDecimal rgMny; // 人工费
    @TableField(value="material_mny")
    private BigDecimal materialMny; // 材料费
    @TableField(value="equipment_mny")
    private BigDecimal equipmentMny; // 机械使用费
    @TableField(value="zj_mny")
    private BigDecimal zjMny; // 其他直接费
    @TableField(value="jj_mny")
    private BigDecimal jjMny; // 现场间接费
    @TableField(value="sub_mny")
    private BigDecimal subMny; // 专业分包
    @TableField(value="other_mny")
    private BigDecimal otherMny; // 其他
    @TableField(value="management_mny")
    private BigDecimal managementMny; // 应交公司管理费
    @TableField(value="profit_mny")
    private BigDecimal profitMny; // 应上交公司利润
    @TableField(value="share_profit_mny")
    private BigDecimal shareProfitMny; // 项目分配兑现利润
    @TableField(value="received_mny")
    private BigDecimal receivedMny; // 已收工程款
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectOrgId() {
        return projectOrgId;
    }

    public void setProjectOrgId(Long projectOrgId) {
        this.projectOrgId = projectOrgId;
    }
    public String getProjectOrgCode() {
        return projectOrgCode;
    }

    public void setProjectOrgCode(String projectOrgCode) {
        this.projectOrgCode = projectOrgCode;
    }
    public String getProjectOrgName() {
        return projectOrgName;
    }

    public void setProjectOrgName(String projectOrgName) {
        this.projectOrgName = projectOrgName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getNodeStage() {
        return nodeStage;
    }

    public void setNodeStage(String nodeStage) {
        this.nodeStage = nodeStage;
    }
    public BigDecimal getEngineeringMny() {
        return engineeringMny;
    }

    public void setEngineeringMny(BigDecimal engineeringMny) {
        this.engineeringMny = engineeringMny;
    }
    public BigDecimal getEngineeringTax() {
        return engineeringTax;
    }

    public void setEngineeringTax(BigDecimal engineeringTax) {
        this.engineeringTax = engineeringTax;
    }
    public BigDecimal getRgMny() {
        return rgMny;
    }

    public void setRgMny(BigDecimal rgMny) {
        this.rgMny = rgMny;
    }
    public BigDecimal getMaterialMny() {
        return materialMny;
    }

    public void setMaterialMny(BigDecimal materialMny) {
        this.materialMny = materialMny;
    }
    public BigDecimal getEquipmentMny() {
        return equipmentMny;
    }

    public void setEquipmentMny(BigDecimal equipmentMny) {
        this.equipmentMny = equipmentMny;
    }
    public BigDecimal getZjMny() {
        return zjMny;
    }

    public void setZjMny(BigDecimal zjMny) {
        this.zjMny = zjMny;
    }
    public BigDecimal getJjMny() {
        return jjMny;
    }

    public void setJjMny(BigDecimal jjMny) {
        this.jjMny = jjMny;
    }
    public BigDecimal getSubMny() {
        return subMny;
    }

    public void setSubMny(BigDecimal subMny) {
        this.subMny = subMny;
    }
    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }
    public BigDecimal getManagementMny() {
        return managementMny;
    }

    public void setManagementMny(BigDecimal managementMny) {
        this.managementMny = managementMny;
    }
    public BigDecimal getProfitMny() {
        return profitMny;
    }

    public void setProfitMny(BigDecimal profitMny) {
        this.profitMny = profitMny;
    }
    public BigDecimal getShareProfitMny() {
        return shareProfitMny;
    }

    public void setShareProfitMny(BigDecimal shareProfitMny) {
        this.shareProfitMny = shareProfitMny;
    }
    public BigDecimal getReceivedMny() {
        return receivedMny;
    }

    public void setReceivedMny(BigDecimal receivedMny) {
        this.receivedMny = receivedMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-riskmortgage-impl-3.0.0-20231123.092538-86-sources.jar: com/ejianc/business/collect/bean/CollectEntity.java <==
package com.ejianc.business.collect.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 兑现计算汇总表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_collect")
public class CollectEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_org_id")
    private Long projectOrgId; // 项目所属组织id
    @TableField(value="project_org_code")
    private String projectOrgCode; // 项目所属组织编码
    @TableField(value="project_org_name")
    private String projectOrgName; // 项目所属组织名称
    @TableField(value="employee_id")
    private Long employeeId; // 经办人id
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办人部门id
    @TableField(value="department_code")
    private String departmentCode; // 经办人部门编码
    @TableField(value="department_name")
    private String departmentName; // 经办人部门名称
    @TableField(value="node_stage")
    private String nodeStage; // 节点阶段
    @TableField(value="engineering_mny")
    private BigDecimal engineeringMny; // 工程造价
    @TableField(value="engineering_tax")
    private BigDecimal engineeringTax; // 工程税金
    @TableField(value="rg_mny")
    private BigDecimal rgMny; // 人工费
    @TableField(value="material_mny")
    private BigDecimal materialMny; // 材料费
    @TableField(value="equipment_mny")
    private BigDecimal equipmentMny; // 机械使用费
    @TableField(value="zj_mny")
    private BigDecimal zjMny; // 其他直接费
    @TableField(value="jj_mny")
    private BigDecimal jjMny; // 现场间接费
    @TableField(value="sub_mny")
    private BigDecimal subMny; // 专业分包
    @TableField(value="other_mny")
    private BigDecimal otherMny; // 其他
    @TableField(value="management_mny")
    private BigDecimal managementMny; // 应交公司管理费
    @TableField(value="profit_mny")
    private BigDecimal profitMny; // 应上交公司利润
    @TableField(value="share_profit_mny")
    private BigDecimal shareProfitMny; // 项目分配兑现利润
    @TableField(value="received_mny")
    private BigDecimal receivedMny; // 已收工程款
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="approve_flag")
    private Integer approveFlag; // 是否被兑现审批引用  1-引用  0-未引用

    public Integer getApproveFlag() {
        return approveFlag;
    }

    public void setApproveFlag(Integer approveFlag) {
        this.approveFlag = approveFlag;
    }
    
    

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getProjectOrgId() {
        return projectOrgId;
    }

    public void setProjectOrgId(Long projectOrgId) {
        this.projectOrgId = projectOrgId;
    }
    public String getProjectOrgCode() {
        return projectOrgCode;
    }

    public void setProjectOrgCode(String projectOrgCode) {
        this.projectOrgCode = projectOrgCode;
    }
    public String getProjectOrgName() {
        return projectOrgName;
    }

    public void setProjectOrgName(String projectOrgName) {
        this.projectOrgName = projectOrgName;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getNodeStage() {
        return nodeStage;
    }

    public void setNodeStage(String nodeStage) {
        this.nodeStage = nodeStage;
    }
    public BigDecimal getEngineeringMny() {
        return engineeringMny;
    }

    public void setEngineeringMny(BigDecimal engineeringMny) {
        this.engineeringMny = engineeringMny;
    }
    public BigDecimal getEngineeringTax() {
        return engineeringTax;
    }

    public void setEngineeringTax(BigDecimal engineeringTax) {
        this.engineeringTax = engineeringTax;
    }
    public BigDecimal getRgMny() {
        return rgMny;
    }

    public void setRgMny(BigDecimal rgMny) {
        this.rgMny = rgMny;
    }
    public BigDecimal getMaterialMny() {
        return materialMny;
    }

    public void setMaterialMny(BigDecimal materialMny) {
        this.materialMny = materialMny;
    }
    public BigDecimal getEquipmentMny() {
        return equipmentMny;
    }

    public void setEquipmentMny(BigDecimal equipmentMny) {
        this.equipmentMny = equipmentMny;
    }
    public BigDecimal getZjMny() {
        return zjMny;
    }

    public void setZjMny(BigDecimal zjMny) {
        this.zjMny = zjMny;
    }
    public BigDecimal getJjMny() {
        return jjMny;
    }

    public void setJjMny(BigDecimal jjMny) {
        this.jjMny = jjMny;
    }
    public BigDecimal getSubMny() {
        return subMny;
    }

    public void setSubMny(BigDecimal subMny) {
        this.subMny = subMny;
    }
    public BigDecimal getOtherMny() {
        return otherMny;
    }

    public void setOtherMny(BigDecimal otherMny) {
        this.otherMny = otherMny;
    }
    public BigDecimal getManagementMny() {
        return managementMny;
    }

    public void setManagementMny(BigDecimal managementMny) {
        this.managementMny = managementMny;
    }
    public BigDecimal getProfitMny() {
        return profitMny;
    }

    public void setProfitMny(BigDecimal profitMny) {
        this.profitMny = profitMny;
    }
    public BigDecimal getShareProfitMny() {
        return shareProfitMny;
    }

    public void setShareProfitMny(BigDecimal shareProfitMny) {
        this.shareProfitMny = shareProfitMny;
    }
    public BigDecimal getReceivedMny() {
        return receivedMny;
    }

    public void setReceivedMny(BigDecimal receivedMny) {
        this.receivedMny = receivedMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
